'''Addresses of predeployed smart contracts'''

DEPLOYMENT_CONTROLLER_ADMIN_ADDRESS = '0xD2004000000000000000000000000000000000D2'
DEPLOYMENT_CONTROLLER_ADDRESS = '0xD2002000000000000000000000000000000000d2'
DEPLOYMENT_CONTROLLER_IMPLEMENTATION_ADDRESS = '0xD2003000000000000000000000000000000000D2'
